@@ -1,6 +1,5 @@
 """Torch dataset for sites."""
 
-import numpy as np
 import pandas as pd
 import xarray as xr
 from torch.utils.data import Dataset
@@ -24,9 +23,11 @@ from ocf_data_sampler.select import (
     find_contiguous_t0_periods,
     intersection_of_multiple_dataframes_of_periods,
 )
+from ocf_data_sampler.torch_datasets.datasets.picklecache import PickleCacheMixin
 from ocf_data_sampler.torch_datasets.utils import (
     add_alterate_coordinate_projections,
     config_normalization_values_to_dicts,
+    diff_nwp_data,
     fill_nans_in_arrays,
     find_valid_time_periods,
     merge_dicts,
@@ -57,6 +58,7 @@ def get_locations(site_xr: xr.Dataset) -> list[Location]:
 
     return locations
 
+
 def process_and_combine_datasets(
     dataset_dict: dict,
     config: Configuration,
@@ -73,19 +75,17 @@ def process_and_combine_datasets(
         means_dict: Nested dictionary of mean values for the input data sources
         stds_dict: Nested dictionary of std values for the input data sources
     """
-    numpy_modalities = []
+    numpy_modalities = [{"t0": t0.timestamp()}]
 
     if "nwp" in dataset_dict:
         nwp_numpy_modalities = {}
 
         for nwp_key, da_nwp in dataset_dict["nwp"].items():
 
-            # Standardise and convert to NumpyBatch
+            channel_means = means_dict["nwp"][nwp_key]
+            channel_stds = stds_dict["nwp"][nwp_key]
 
-            da_channel_means = means_dict["nwp"][nwp_key]
-            da_channel_stds = stds_dict["nwp"][nwp_key]
-
-            da_nwp = (da_nwp - da_channel_means) / da_channel_stds
+            da_nwp = (da_nwp - channel_means) / channel_stds
 
             nwp_numpy_modalities[nwp_key] = convert_nwp_to_numpy_sample(da_nwp)
 
@@ -96,16 +96,16 @@ def process_and_combine_datasets(
         da_sat = dataset_dict["sat"]
 
         # Standardise and convert to NumpyBatch
-        da_channel_means = means_dict["sat"]
-        da_channel_stds = stds_dict["sat"]
+        channel_means = means_dict["sat"]
+        channel_stds = stds_dict["sat"]
 
-        da_sat = (da_sat - da_channel_means) / da_channel_stds
+        da_sat = (da_sat - channel_means) / channel_stds
 
         numpy_modalities.append(convert_satellite_to_numpy_sample(da_sat))
 
     if "site" in dataset_dict:
         da_sites = dataset_dict["site"]
-        da_sites = da_sites / da_sites.capacity_kwp
+        da_sites = da_sites / da_sites.capacity_kwp.values
 
         # Convert to NumpyBatch
         numpy_modalities.append(convert_site_to_numpy_sample(da_sites))
@@ -139,12 +139,12 @@ def process_and_combine_datasets(
 
     # Combine all the modalities and fill NaNs
     combined_sample = merge_dicts(numpy_modalities)
-    combined_sample = fill_nans_in_arrays(combined_sample)
+    combined_sample = fill_nans_in_arrays(combined_sample, config=config)
 
     return combined_sample
 
 
-class SitesDataset(Dataset):
+class SitesDataset(PickleCacheMixin, Dataset):
     """A torch Dataset for creating PVNet Site samples."""
 
     def __init__(
@@ -160,6 +160,8 @@ class SitesDataset(Dataset):
             start_time: Limit the init-times to be after this
             end_time: Limit the init-times to be before this
         """
+        super().__init__()
+
         config = load_yaml_configuration(config_filename)
         datasets_dict = get_dataset_dict(config.input_data)
 
@@ -258,6 +260,7 @@ class SitesDataset(Dataset):
 
     @override
     def __getitem__(self, idx: int) -> dict:
+
         # Get the coordinates of the sample
         t0, site_id = self.valid_t0_and_site_ids.iloc[idx]
 
@@ -276,8 +279,8 @@ class SitesDataset(Dataset):
         """
         sample_dict = slice_datasets_by_space(self.datasets_dict, location, self.config)
         sample_dict = slice_datasets_by_time(sample_dict, t0, self.config)
-
         sample_dict = tensorstore_compute(sample_dict)
+        sample_dict = diff_nwp_data(sample_dict, self.config)
 
         return process_and_combine_datasets(
             sample_dict,
@@ -301,7 +304,7 @@ class SitesDataset(Dataset):
         return self._get_sample(t0, location)
 
 
-class SitesDatasetConcurrent(Dataset):
+class SitesDatasetConcurrent(PickleCacheMixin, Dataset):
     """A torch Dataset for creating PVNet Site batches with samples for all sites."""
 
     def __init__(
@@ -317,6 +320,8 @@ class SitesDatasetConcurrent(Dataset):
             start_time: Limit the init-times to be after this
             end_time: Limit the init-times to be before this
         """
+        super().__init__()
+
         config = load_yaml_configuration(config_filename)
         datasets_dict = get_dataset_dict(config.input_data)
 
@@ -325,7 +330,12 @@ class SitesDatasetConcurrent(Dataset):
         self.config = config
 
         # get all locations
-        self.locations = get_locations(datasets_dict["site"])
+        locations = get_locations(datasets_dict["site"])
+        self.locations = add_alterate_coordinate_projections(
+            locations,
+            datasets_dict,
+            primary_coords="lon_lat",
+        )
 
         # Get t0 times where all input data is available
         valid_t0s = self.find_valid_t0s(datasets_dict)
@@ -414,6 +424,7 @@ class SitesDatasetConcurrent(Dataset):
         # slice by time first as we want to keep all site id info
         sample_dict = slice_datasets_by_time(self.datasets_dict, t0, self.config)
         sample_dict = tensorstore_compute(sample_dict)
+        sample_dict = diff_nwp_data(sample_dict, self.config)
 
         site_samples = []
 
@@ -429,25 +440,3 @@ class SitesDatasetConcurrent(Dataset):
             site_samples.append(site_numpy_sample)
 
         return stack_np_samples_into_batch(site_samples)
-
-
-def coarsen_data(xr_data: xr.Dataset, coarsen_to_deg: float = 0.1) -> xr.Dataset:
-    """Coarsen the data to a specified resolution in degrees.
-
-    Args:
-        xr_data: xarray dataset to coarsen
-        coarsen_to_deg: resolution to coarsen to in degrees
-    """
-    if "latitude" in xr_data.coords and "longitude" in xr_data.coords:
-        step = np.abs(xr_data.latitude.values[1] - xr_data.latitude.values[0])
-        step = np.round(step, 4)
-        coarsen_factor = int(coarsen_to_deg / step)
-        if coarsen_factor > 1:
-            xr_data = xr_data.coarsen(
-                latitude=coarsen_factor,
-                longitude=coarsen_factor,
-                boundary="pad",
-                coord_func="min",
-            ).mean()
-
-    return xr_data
