@@ -15,7 +15,16 @@ def minutes(minutes: int | list[float]) -> pd.Timedelta | pd.TimedeltaIndex:
 
 def compute(xarray_dict: dict) -> dict:
     """Eagerly load a nested dictionary of xarray DataArrays."""
-    for k, v in xarray_dict.items():
+    # Load these keys first because they don't use tensorstore
+    priority_keys = ["gsp", "site"]
+    for key in priority_keys:
+        if key in xarray_dict:
+            xarray_dict[key] = xarray_dict[key].compute()
+
+    # Load the rest
+    keys = [k for k in xarray_dict if k not in priority_keys]
+    for k in keys:
+        v = xarray_dict[k]
         if isinstance(v, dict):
             xarray_dict[k] = compute(v)
         else:
